<!DOCTYPE TS><TS>
<context>
    <name>AboutDialog</name>
    <message>
        <source>Hydrogen - About</source>
        <translation type="obsolete">Hydrogen - A propos</translation>
    </message>
    <message>
        <source>&lt;i&gt;Compiled modules: </source>
        <translation type="obsolete">&lt;i&gt;Modules compilés:</translation>
    </message>
    <message>
        <source>&lt;b&gt;Project page&lt;/b&gt;&lt;br&gt;</source>
        <translation>&lt;b&gt;Page de projet&lt;/b&gt;&lt;br&gt;</translation>
    </message>
    <message>
        <source>&lt;b&gt;Mailing lists:&lt;/b&gt;&lt;br&gt;</source>
        <translation>&lt;b&gt;Liste de diffusion:&lt;/b&gt;&lt;br&gt;</translation>
    </message>
    <message>
        <source>&lt;b&gt;Authors:&lt;/b&gt;&lt;br&gt;</source>
        <translation>&lt;b&gt;Auteurs:&lt;/b&gt;&lt;br&gt;</translation>
    </message>
    <message>
        <source>Maintainer, main coder&lt;br&gt;&lt;/ul&gt;&lt;/i&gt;&lt;/p&gt;&lt;br&gt;</source>
        <translation>Mainteneur, programmeur principal&lt;br&lt;/ul&gt;&lt;/i&gt;&lt;/p&gt;&lt;br&gt;</translation>
    </message>
    <message>
        <source>Drumkits and demo songs&lt;br&gt;&lt;/ul&gt;&lt;/i&gt;&lt;/p&gt;</source>
        <translation>Kits de batterie et morceaux de démo&lt;br&gt;&lt;/ul&gt;&lt;/i&gt;&lt;/p&gt;</translation>
    </message>
    <message>
        <source>&lt;i&gt;&lt;ul&gt;Testing, ideas..&lt;/ul&gt;&lt;/i&gt;&lt;/p&gt;&lt;br&gt;</source>
        <translation>&lt;i&gt;&lt;ul&gt;Test, idées...&lt;/ul&gt;&lt;/i&gt;&lt;/p&gt;&lt;br&gt;</translation>
    </message>
    <message>
        <source>&lt;i&gt;&lt;ul&gt;NetBSD patch&lt;/ul&gt;&lt;/i&gt;&lt;/p&gt;&lt;br&gt;</source>
        <translation>&lt;i&gt;&lt;ul&gt;Patch pour NetBSD&lt;/ul&gt;&lt;/i&gt;&lt;/p&gt;&lt;br&gt;</translation>
    </message>
    <message>
        <source>&lt;i&gt;&lt;ul&gt;Faq, testing&lt;/ul&gt;&lt;/i&gt;&lt;/p&gt;&lt;br&gt;</source>
        <translation>&lt;i&gt;&lt;ul&gt;Faq, test&lt;/ul&gt;&lt;/i&gt;&lt;/p&gt;&lt;br&gt;</translation>
    </message>
    <message>
        <source>&lt;i&gt;&lt;ul&gt;Patches, testing&lt;/ul&gt;&lt;/i&gt;&lt;/p&gt;&lt;br&gt;</source>
        <translation>&lt;i&gt;&lt;ul&gt;Patchs, test&lt;/ul&gt;&lt;/i&gt;&lt;/p&gt;&lt;br&gt;</translation>
    </message>
    <message>
        <source>&lt;i&gt;&lt;ul&gt;Packages&lt;/ul&gt;&lt;/i&gt;&lt;/p&gt;&lt;br&gt;</source>
        <translation>&lt;i&gt;&lt;ul&gt;Paquetage&lt;/ul&gt;&lt;/i&gt;&lt;/p&gt;&lt;br&gt;</translation>
    </message>
    <message>
        <source>&lt;i&gt;&lt;ul&gt;Russian translation&lt;br&gt;&lt;/ul&gt;&lt;/i&gt;&lt;/p&gt;&lt;br&gt;</source>
        <translation>&lt;i&gt;&lt;ul&gt;Traduction Russe&lt;br&gt;&lt;/ul&gt;&lt;/i&gt;&lt;/p&gt;&lt;br&gt;</translation>
    </message>
    <message>
        <source>&lt;i&gt;&lt;ul&gt;Jack patches, bug fix&lt;br&gt;&lt;/ul&gt;&lt;/i&gt;&lt;/p&gt;&lt;br&gt;</source>
        <translation>&lt;i&gt;&lt;ul&gt;Patches Jack, correction de bugs&lt;br&gt;&lt;/ul&gt;&lt;/i&gt;&lt;/p&gt;&lt;br&gt;</translation>
    </message>
    <message>
        <source>&lt;i&gt;&lt;ul&gt;Spanish manual&lt;/ul&gt;&lt;/i&gt;&lt;/p&gt;&lt;br&gt;</source>
        <translation>&lt;i&gt;&lt;ul&gt;Manuel Espagnol&lt;/ul&gt;&lt;/i&gt;&lt;/p&gt;&lt;br&gt;</translation>
    </message>
    <message>
        <source>&lt;i&gt;&lt;ul&gt;Bug reports, ideas&lt;/ul&gt;&lt;/i&gt;&lt;/p&gt;&lt;br&gt;</source>
        <translation>&lt;i&gt;&lt;ul&gt;Rapports de bugs, idées&lt;/ul&gt;&lt;/i&gt;&lt;/p&gt;&lt;br&gt;</translation>
    </message>
    <message>
        <source>&lt;i&gt;&lt;ul&gt;Demo songs, testing&lt;/ul&gt;&lt;/i&gt;&lt;/p&gt;&lt;br&gt;</source>
        <translation>&lt;i&gt;&lt;ul&gt;Morceaux de demo, test&lt;/ul&gt;&lt;/i&gt;&lt;/p&gt;&lt;br&gt;</translation>
    </message>
    <message>
        <source>&lt;i&gt;&lt;ul&gt;Jack patches&lt;/ul&gt;&lt;/i&gt;&lt;/p&gt;&lt;br&gt;</source>
        <translation>&lt;i&gt;&lt;ul&gt;Patches Jack&lt;/ul&gt;&lt;/i&gt;&lt;/p&gt;&lt;br&gt;</translation>
    </message>
    <message>
        <source>&lt;i&gt;&lt;ul&gt;German manual&lt;/ul&gt;&lt;/i&gt;&lt;/p&gt;&lt;br&gt;</source>
        <translation>&lt;i&gt;&lt;ul&gt;Manuel Allemand&lt;/ul&gt;&lt;/i&gt;&lt;/p&gt;&lt;br&gt;</translation>
    </message>
    <message>
        <source>&lt;i&gt;&lt;ul&gt;French translation&lt;/ul&gt;&lt;/i&gt;&lt;/p&gt;&lt;br&gt;</source>
        <translation>&lt;i&gt;&lt;ul&gt;Traduction Francaise&lt;/ul&gt;&lt;/i&gt;&lt;/p&gt;&lt;br&gt;</translation>
    </message>
    <message>
        <source>&lt;i&gt;&lt;ul&gt;Spanish translation&lt;/ul&gt;&lt;/i&gt;&lt;/p&gt;&lt;br&gt;</source>
        <translation>&lt;i&gt;&lt;ul&gt;Traduction Espagnole&lt;/ul&gt;&lt;/i&gt;&lt;/p&gt;&lt;br&gt;</translation>
    </message>
    <message>
        <source>&lt;i&gt;&lt;ul&gt;Italian manual&lt;/ul&gt;&lt;/i&gt;&lt;/p&gt;&lt;br&gt;</source>
        <translation>&lt;i&gt;&lt;ul&gt;Manuel Italien&lt;/ul&gt;&lt;/i&gt;&lt;/p&gt;&lt;br&gt;</translation>
    </message>
    <message>
        <source>About</source>
        <translation>A propos</translation>
    </message>
    <message>
        <source>&lt;i&gt;Compiled modules: %1&lt;/i&gt;&lt;/center&gt;</source>
        <translation>&lt;i&gt;Modules Compilés: %1&lt;/i&gt;&lt;/center&gt;</translation>
    </message>
    <message>
        <source>&lt;i&gt;&lt;ul&gt;Bug fix, test&lt;/ul&gt;&lt;/i&gt;&lt;/p&gt;&lt;br&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&lt;i&gt;&lt;ul&gt;Portuguese(Brazil) translation&lt;/ul&gt;&lt;/i&gt;&lt;/p&gt;&lt;br&gt;</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>AboutDialog_UI</name>
    <message>
        <source>About Hydrogen...</source>
        <translation>A propos d&apos;Hydrogen...</translation>
    </message>
    <message>
        <source>Ok</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>About</source>
        <translation>A propos</translation>
    </message>
    <message>
        <source>###</source>
        <translation></translation>
    </message>
    <message>
        <source>Authors</source>
        <translation>Auteurs</translation>
    </message>
    <message>
        <source>License</source>
        <translation>Licence</translation>
    </message>
    <message>
        <source>This program is distributed under the terms of the GPL v2.

<byte value="x9"/><byte value="x9"/>    GNU GENERAL PUBLIC LICENSE
<byte value="x9"/><byte value="x9"/>       Version 2, June 1991

 Copyright (C) 1989, 1991 Free Software Foundation, Inc.
                          675 Mass Ave, Cambridge, MA 02139, USA
 Everyone is permitted to copy and distribute verbatim copies
 of this license document, but changing it is not allowed.

<byte value="x9"/><byte value="x9"/><byte value="x9"/>    Preamble

  The licenses for most software are designed to take away your
freedom to share and change it.  By contrast, the GNU General Public
License is intended to guarantee your freedom to share and change free
software--to make sure the software is free for all its users.  This
General Public License applies to most of the Free Software
Foundation&apos;s software and to any other program whose authors commit to
using it.  (Some other Free Software Foundation software is covered by
the GNU Library General Public License instead.)  You can apply it to
your programs, too.

  When we speak of free software, we are referring to freedom, not
price.  Our General Public Licenses are designed to make sure that you
have the freedom to distribute copies of free software (and charge for
this service if you wish), that you receive source code or can get it
if you want it, that you can change the software or use pieces of it
in new free programs; and that you know you can do these things.

  To protect your rights, we need to make restrictions that forbid
anyone to deny you these rights or to ask you to surrender the rights.
These restrictions translate to certain responsibilities for you if you
distribute copies of the software, or if you modify it.

  For example, if you distribute copies of such a program, whether
gratis or for a fee, you must give the recipients all the rights that
you have.  You must make sure that they, too, receive or can get the
source code.  And you must show them these terms so they know their
rights.

  We protect your rights with two steps: (1) copyright the software, and
(2) offer you this license which gives you legal permission to copy,
distribute and/or modify the software.

  Also, for each author&apos;s protection and ours, we want to make certain
that everyone understands that there is no warranty for this free
software.  If the software is modified by someone else and passed on, we
want its recipients to know that what they have is not the original, so
that any problems introduced by others will not reflect on the original
authors&apos; reputations.

  Finally, any free program is threatened constantly by software
patents.  We wish to avoid the danger that redistributors of a free
program will individually obtain patent licenses, in effect making the
program proprietary.  To prevent this, we have made it clear that any
patent must be licensed for everyone&apos;s free use or not licensed at all.

  The precise terms and conditions for copying, distribution and
modification follow.
 
<byte value="x9"/><byte value="x9"/>    GNU GENERAL PUBLIC LICENSE
   TERMS AND CONDITIONS FOR COPYING, DISTRIBUTION AND MODIFICATION

  0. This License applies to any program or other work which contains
a notice placed by the copyright holder saying it may be distributed
under the terms of this General Public License.  The &quot;Program&quot;, below,
refers to any such program or work, and a &quot;work based on the Program&quot;
means either the Program or any derivative work under copyright law:
that is to say, a work containing the Program or a portion of it,
either verbatim or with modifications and/or translated into another
language.  (Hereinafter, translation is included without limitation in
the term &quot;modification&quot;.)  Each licensee is addressed as &quot;you&quot;.

Activities other than copying, distribution and modification are not
covered by this License; they are outside its scope.  The act of
running the Program is not restricted, and the output from the Program
is covered only if its contents constitute a work based on the
Program (independent of having been made by running the Program).
Whether that is true depends on what the Program does.

  1. You may copy and distribute verbatim copies of the Program&apos;s
source code as you receive it, in any medium, provided that you
conspicuously and appropriately publish on each copy an appropriate
copyright notice and disclaimer of warranty; keep intact all the
notices that refer to this License and to the absence of any warranty;
and give any other recipients of the Program a copy of this License
along with the Program.

You may charge a fee for the physical act of transferring a copy, and
you may at your option offer warranty protection in exchange for a fee.

  2. You may modify your copy or copies of the Program or any portion
of it, thus forming a work based on the Program, and copy and
distribute such modifications or work under the terms of Section 1
above, provided that you also meet all of these conditions:

    a) You must cause the modified files to carry prominent notices
    stating that you changed the files and the date of any change.

    b) You must cause any work that you distribute or publish, that in
    whole or in part contains or is derived from the Program or any
    part thereof, to be licensed as a whole at no charge to all third
    parties under the terms of this License.

    c) If the modified program normally reads commands interactively
    when run, you must cause it, when started running for such
    interactive use in the most ordinary way, to print or display an
    announcement including an appropriate copyright notice and a
    notice that there is no warranty (or else, saying that you provide
    a warranty) and that users may redistribute the program under
    these conditions, and telling the user how to view a copy of this
    License.  (Exception: if the Program itself is interactive but
    does not normally print such an announcement, your work based on
    the Program is not required to print an announcement.)
 
These requirements apply to the modified work as a whole.  If
identifiable sections of that work are not derived from the Program,
and can be reasonably considered independent and separate works in
themselves, then this License, and its terms, do not apply to those
sections when you distribute them as separate works.  But when you
distribute the same sections as part of a whole which is a work based
on the Program, the distribution of the whole must be on the terms of
this License, whose permissions for other licensees extend to the
entire whole, and thus to each and every part regardless of who wrote it.

Thus, it is not the intent of this section to claim rights or contest
your rights to work written entirely by you; rather, the intent is to
exercise the right to control the distribution of derivative or
collective works based on the Program.

In addition, mere aggregation of another work not based on the Program
with the Program (or with a work based on the Program) on a volume of
a storage or distribution medium does not bring the other work under
the scope of this License.

  3. You may copy and distribute the Program (or a work based on it,
under Section 2) in object code or executable form under the terms of
Sections 1 and 2 above provided that you also do one of the following:

    a) Accompany it with the complete corresponding machine-readable
    source code, which must be distributed under the terms of Sections
    1 and 2 above on a medium customarily used for software interchange; or,

    b) Accompany it with a written offer, valid for at least three
    years, to give any third party, for a charge no more than your
    cost of physically performing source distribution, a complete
    machine-readable copy of the corresponding source code, to be
    distributed under the terms of Sections 1 and 2 above on a medium
    customarily used for software interchange; or,

    c) Accompany it with the information you received as to the offer
    to distribute corresponding source code.  (This alternative is
    allowed only for noncommercial distribution and only if you
    received the program in object code or executable form with such
    an offer, in accord with Subsection b above.)

The source code for a work means the preferred form of the work for
making modifications to it.  For an executable work, complete source
code means all the source code for all modules it contains, plus any
associated interface definition files, plus the scripts used to
control compilation and installation of the executable.  However, as a
special exception, the source code distributed need not include
anything that is normally distributed (in either source or binary
form) with the major components (compiler, kernel, and so on) of the
operating system on which the executable runs, unless that component
itself accompanies the executable.

If distribution of executable or object code is made by offering
access to copy from a designated place, then offering equivalent
access to copy the source code from the same place counts as
distribution of the source code, even though third parties are not
compelled to copy the source along with the object code.
 
  4. You may not copy, modify, sublicense, or distribute the Program
except as expressly provided under this License.  Any attempt
otherwise to copy, modify, sublicense or distribute the Program is
void, and will automatically terminate your rights under this License.
However, parties who have received copies, or rights, from you under
this License will not have their licenses terminated so long as such
parties remain in full compliance.

  5. You are not required to accept this License, since you have not
signed it.  However, nothing else grants you permission to modify or
distribute the Program or its derivative works.  These actions are
prohibited by law if you do not accept this License.  Therefore, by
modifying or distributing the Program (or any work based on the
Program), you indicate your acceptance of this License to do so, and
all its terms and conditions for copying, distributing or modifying
the Program or works based on it.

  6. Each time you redistribute the Program (or any work based on the
Program), the recipient automatically receives a license from the
original licensor to copy, distribute or modify the Program subject to
these terms and conditions.  You may not impose any further
restrictions on the recipients&apos; exercise of the rights granted herein.
You are not responsible for enforcing compliance by third parties to
this License.

  7. If, as a consequence of a court judgment or allegation of patent
infringement or for any other reason (not limited to patent issues),
conditions are imposed on you (whether by court order, agreement or
otherwise) that contradict the conditions of this License, they do not
excuse you from the conditions of this License.  If you cannot
distribute so as to satisfy simultaneously your obligations under this
License and any other pertinent obligations, then as a consequence you
may not distribute the Program at all.  For example, if a patent
license would not permit royalty-free redistribution of the Program by
all those who receive copies directly or indirectly through you, then
the only way you could satisfy both it and this License would be to
refrain entirely from distribution of the Program.

If any portion of this section is held invalid or unenforceable under
any particular circumstance, the balance of the section is intended to
apply and the section as a whole is intended to apply in other
circumstances.

It is not the purpose of this section to induce you to infringe any
patents or other property right claims or to contest validity of any
such claims; this section has the sole purpose of protecting the
integrity of the free software distribution system, which is
implemented by public license practices.  Many people have made
generous contributions to the wide range of software distributed
through that system in reliance on consistent application of that
system; it is up to the author/donor to decide if he or she is willing
to distribute software through any other system and a licensee cannot
impose that choice.

This section is intended to make thoroughly clear what is believed to
be a consequence of the rest of this License.
 
  8. If the distribution and/or use of the Program is restricted in
certain countries either by patents or by copyrighted interfaces, the
original copyright holder who places the Program under this License
may add an explicit geographical distribution limitation excluding
those countries, so that distribution is permitted only in or among
countries not thus excluded.  In such case, this License incorporates
the limitation as if written in the body of this License.

  9. The Free Software Foundation may publish revised and/or new versions
of the General Public License from time to time.  Such new versions will
be similar in spirit to the present version, but may differ in detail to
address new problems or concerns.

Each version is given a distinguishing version number.  If the Program
specifies a version number of this License which applies to it and &quot;any
later version&quot;, you have the option of following the terms and conditions
either of that version or of any later version published by the Free
Software Foundation.  If the Program does not specify a version number of
this License, you may choose any version ever published by the Free Software
Foundation.

  10. If you wish to incorporate parts of the Program into other free
programs whose distribution conditions are different, write to the author
to ask for permission.  For software which is copyrighted by the Free
Software Foundation, write to the Free Software Foundation; we sometimes
make exceptions for this.  Our decision will be guided by the two goals
of preserving the free status of all derivatives of our free software and
of promoting the sharing and reuse of software generally.

<byte value="x9"/><byte value="x9"/><byte value="x9"/>    NO WARRANTY

  11. BECAUSE THE PROGRAM IS LICENSED FREE OF CHARGE, THERE IS NO WARRANTY
FOR THE PROGRAM, TO THE EXTENT PERMITTED BY APPLICABLE LAW.  EXCEPT WHEN
OTHERWISE STATED IN WRITING THE COPYRIGHT HOLDERS AND/OR OTHER PARTIES
PROVIDE THE PROGRAM &quot;AS IS&quot; WITHOUT WARRANTY OF ANY KIND, EITHER EXPRESSED
OR IMPLIED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.  THE ENTIRE RISK AS
TO THE QUALITY AND PERFORMANCE OF THE PROGRAM IS WITH YOU.  SHOULD THE
PROGRAM PROVE DEFECTIVE, YOU ASSUME THE COST OF ALL NECESSARY SERVICING,
REPAIR OR CORRECTION.

  12. IN NO EVENT UNLESS REQUIRED BY APPLICABLE LAW OR AGREED TO IN WRITING
WILL ANY COPYRIGHT HOLDER, OR ANY OTHER PARTY WHO MAY MODIFY AND/OR
REDISTRIBUTE THE PROGRAM AS PERMITTED ABOVE, BE LIABLE TO YOU FOR DAMAGES,
INCLUDING ANY GENERAL, SPECIAL, INCIDENTAL OR CONSEQUENTIAL DAMAGES ARISING
OUT OF THE USE OR INABILITY TO USE THE PROGRAM (INCLUDING BUT NOT LIMITED
TO LOSS OF DATA OR DATA BEING RENDERED INACCURATE OR LOSSES SUSTAINED BY
YOU OR THIRD PARTIES OR A FAILURE OF THE PROGRAM TO OPERATE WITH ANY OTHER
PROGRAMS), EVEN IF SUCH HOLDER OR OTHER PARTY HAS BEEN ADVISED OF THE
POSSIBILITY OF SUCH DAMAGES.

<byte value="x9"/><byte value="x9"/>     END OF TERMS AND CONDITIONS

<byte value="x9"/>    How to Apply These Terms to Your New Programs

  If you develop a new program, and you want it to be of the greatest
possible use to the public, the best way to achieve this is to make it
free software which everyone can redistribute and change under these terms.

  To do so, attach the following notices to the program.  It is safest
to attach them to the start of each source file to most effectively
convey the exclusion of warranty; and each file should have at least
the &quot;copyright&quot; line and a pointer to where the full notice is found.

    &lt;one line to give the program&apos;s name and a brief idea of what it does.&gt;
    Copyright (C) 19yy  &lt;name of author&gt;

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA


Also add information on how to contact you by electronic and paper mail.

If the program is interactive, make it output a short notice like this
when it starts in an interactive mode:

    Gnomovision version 69, Copyright (C) 19yy name of author
    Gnomovision comes with ABSOLUTELY NO WARRANTY; for details type `show w&apos;.
    This is free software, and you are welcome to redistribute it
    under certain conditions; type `show c&apos; for details.

The hypothetical commands `show w&apos; and `show c&apos; should show the appropriate
parts of the General Public License.  Of course, the commands you use may
be called something other than `show w&apos; and `show c&apos;; they could even be
mouse-clicks or menu items--whatever suits your program.

You should also get your employer (if you work as a programmer) or your
school, if any, to sign a &quot;copyright disclaimer&quot; for the program, if
necessary.  Here is a sample; alter the names:

  Yoyodyne, Inc., hereby disclaims all copyright interest in the program
  `Gnomovision&apos; (which makes passes at compilers) written by James Hacker.

  &lt;signature of Ty Coon&gt;, 1 April 1989
  Ty Coon, President of Vice

This General Public License does not permit incorporating your program into
proprietary programs.  If your program is a subroutine library, you may
consider it more useful to permit linking proprietary applications with the
library.  If this is what you want to do, use the GNU Library General
Public License instead of this License.
</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>AudioEngineInfoForm</name>
    <message>
        <source>Hydrogen - Audio Engine Info</source>
        <translation type="obsolete">Hydrogen - Info du Système Audio</translation>
    </message>
    <message>
        <source>Audio Engine Info</source>
        <translation>Info du Système Audio</translation>
    </message>
</context>
<context>
    <name>AudioEngineInfoForm_UI</name>
    <message>
        <source>Form1</source>
        <translation></translation>
    </message>
    <message>
        <source>Engine Info</source>
        <translation>Information du Système</translation>
    </message>
    <message>
        <source>Playing notes</source>
        <translation>En Lecture</translation>
    </message>
    <message>
        <source>###</source>
        <translation></translation>
    </message>
    <message>
        <source>Process time</source>
        <translation>Temps de traitement</translation>
    </message>
    <message>
        <source>Current pattern</source>
        <translation type="obsolete">Motif courant</translation>
    </message>
    <message>
        <source>Audio engine state</source>
        <translation>Etat du Système Audio</translation>
    </message>
    <message>
        <source>Song state</source>
        <translation>Etat du morceau</translation>
    </message>
    <message>
        <source>Frames</source>
        <translation></translation>
    </message>
    <message>
        <source>Ticks</source>
        <translation>Clics</translation>
    </message>
    <message>
        <source>Audio Driver Info</source>
        <translation>Info du Pilote Audio</translation>
    </message>
    <message>
        <source>Buffer size</source>
        <translation>Taille du Tampon</translation>
    </message>
    <message>
        <source>Audio driver</source>
        <translation>Pilote Audio</translation>
    </message>
    <message>
        <source>Sample rate</source>
        <translation>Taux d&apos;échantillonage</translation>
    </message>
    <message>
        <source>Midi Driver Info</source>
        <translation>Info du Pilote MIDI</translation>
    </message>
    <message>
        <source>Midi driver</source>
        <translation>Pilote MIDI</translation>
    </message>
    <message>
        <source>Close</source>
        <translation type="obsolete">Ferme</translation>
    </message>
    <message>
        <source>Song position</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Patterns</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Selected pattern</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Selected instrument</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DelayFxMixerLine</name>
    <message>
        <source>Delay time</source>
        <translation type="obsolete">Durée de l&apos;écho</translation>
    </message>
    <message>
        <source>Feedback</source>
        <translation type="obsolete">Feedback</translation>
    </message>
    <message>
        <source>Set delay feedback [</source>
        <translation type="obsolete">Ajuste le niveau de feedback [</translation>
    </message>
    <message>
        <source>Set delay time [</source>
        <translation type="obsolete">Ajuste la durée de l&apos;écho</translation>
    </message>
    <message>
        <source>Delay time </source>
        <translation type="obsolete">Durée de l&apos;écho</translation>
    </message>
</context>
<context>
    <name>DrumkitManager</name>
    <message>
        <source>Hydrogen - Drumkit manager</source>
        <translation type="obsolete">Hydrogen - Gestionnaire du kit de batterie</translation>
    </message>
    <message>
        <source>Hydrogen - import drumkit</source>
        <translation type="obsolete">Hydrogen - Importer kit de batterie</translation>
    </message>
    <message>
        <source>Hydrogen - export drumkit</source>
        <translation type="obsolete">Hydrogen - Exporter kit de batterie</translation>
    </message>
    <message>
        <source>Name: &lt;b&gt;%1&lt;/b&gt;</source>
        <translation>Nom: &lt;b&gt;%1&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Author: %1</source>
        <translation>Auteur: %1</translation>
    </message>
    <message>
        <source>Info: &lt;br&gt;%1</source>
        <translation>Info: &lt;br&gt;%1</translation>
    </message>
    <message>
        <source>Drumkit loaded: [%1]</source>
        <translation>Kit Chargé: [%1]</translation>
    </message>
    <message>
        <source>Drumkit manager</source>
        <translation>Gestionnaire de Kit</translation>
    </message>
    <message>
        <source>Import drumkit</source>
        <translation>Importer Kit</translation>
    </message>
    <message>
        <source>Export drumkit</source>
        <translation>Exporter Kit</translation>
    </message>
</context>
<context>
    <name>DrumkitManager_UI</name>
    <message>
        <source>Form1</source>
        <translation></translation>
    </message>
    <message>
        <source>Load</source>
        <translation>Chargement</translation>
    </message>
    <message>
        <source>New Item</source>
        <translation>Nouvel Element</translation>
    </message>
    <message>
        <source>Load drumkit</source>
        <translation>Charger kit de baterrie</translation>
    </message>
    <message>
        <source>Drumkit info</source>
        <translation>Info du kit de batterie</translation>
    </message>
    <message>
        <source>### Drumkit author</source>
        <translation>### Auteur du kit</translation>
    </message>
    <message>
        <source>### Drumkit name</source>
        <translation>### Nom du kit</translation>
    </message>
    <message>
        <source>### Drumkit info</source>
        <translation>### Info du kit</translation>
    </message>
    <message>
        <source>Delete drumkit</source>
        <translation>Effacer kit</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Sauvegarde</translation>
    </message>
    <message>
        <source>Author</source>
        <translation>Auteur</translation>
    </message>
    <message>
        <source>Info</source>
        <translation>Info</translation>
    </message>
    <message>
        <source>Drumkit name</source>
        <translation>Nom du kit</translation>
    </message>
    <message>
        <source>Import</source>
        <translation>Importer</translation>
    </message>
    <message>
        <source>Drumkit filename</source>
        <translation>Nom de fichier du kit</translation>
    </message>
    <message>
        <source>Browse</source>
        <translation>Explorer</translation>
    </message>
    <message>
        <source>### The drumkit will be installed zncxbmzbxcmznxbcmz</source>
        <translation>### Le kit sera installé comme zncxbmzbxcmznxbcmz</translation>
    </message>
    <message>
        <source>&lt;b&gt;
Download more drumkits at &lt;br&gt;
http://hydrogen.sf.net
&lt;/b&gt;</source>
        <translation>&lt;b&gt;
Plus de kits sont en ligne ! Voir :&lt;br&gt;
http://hydrogen.sf.net
&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>Exporter</translation>
    </message>
    <message>
        <source>Drumkit directory</source>
        <translation>Répertoire du kit</translation>
    </message>
</context>
<context>
    <name>ExportSongDialog</name>
    <message>
        <source>Hydrogen - Export song</source>
        <translation type="obsolete">Hydrogen - Exporter le morceau</translation>
    </message>
    <message>
        <source>Wave file (*.wav)</source>
        <translation>Fichier Wave (*.wav)</translation>
    </message>
    <message>
        <source>Exported</source>
        <translation type="obsolete">Exporté</translation>
    </message>
    <message>
        <source>seconds.</source>
        <translation type="obsolete">secondes.</translation>
    </message>
    <message>
        <source>Export song</source>
        <translation>Exporter le morceau</translation>
    </message>
    <message>
        <source>Exported %1</source>
        <translation>%1 Exporté</translation>
    </message>
    <message>
        <source>%1 seconds.</source>
        <translation>%1 secondes.</translation>
    </message>
</context>
<context>
    <name>ExportSongDialog_UI</name>
    <message>
        <source>Form1</source>
        <translation></translation>
    </message>
    <message>
        <source>Export</source>
        <translation>Exporter</translation>
    </message>
    <message>
        <source>Export filename</source>
        <translation>Exporter avec le nom</translation>
    </message>
    <message>
        <source>Browse...</source>
        <translation>Explorer...</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
</context>
<context>
    <name>FilePreview</name>
    <message>
        <source>Play sample</source>
        <translation>Jouer échantillon</translation>
    </message>
    <message>
        <source>Size -</source>
        <translation type="obsolete">Taille -</translation>
    </message>
    <message>
        <source>Size: %1 bytes</source>
        <translation>Taille: %1 bytes</translation>
    </message>
    <message>
        <source>Size: - </source>
        <translation>Taille: -</translation>
    </message>
    <message>
        <source>Samplerate: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Samplerate: - </source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>FxMixerLine</name>
    <message>
        <source>FX on/off</source>
        <translation>Effet on/off</translation>
    </message>
    <message>
        <source>Master output</source>
        <translation>Niveau gén. de sortie</translation>
    </message>
</context>
<context>
    <name>HelpBrowser</name>
    <message>
        <source>Hydrogen - Manual</source>
        <translation type="obsolete">Hydrogen - Manuel</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>Manuel</translation>
    </message>
</context>
<context>
    <name>HydrogenApp</name>
    <message>
        <source>Song Info:     </source>
        <translation>Info Morceau :</translation>
    </message>
    <message>
        <source>Audio files (*.wav *.au *.aiff)</source>
        <translation type="obsolete">Fichiers audio (*.wav *.au *.aiff)</translation>
    </message>
    <message>
        <source>Hydrogen - Load instrument</source>
        <translation type="obsolete">Hydrogen - Charger instrument</translation>
    </message>
    <message>
        <source>No OSS driver support</source>
        <translation>Pas de support OSS</translation>
    </message>
    <message>
        <source>No JACK driver support</source>
        <translation>Pas de support JACK</translation>
    </message>
    <message>
        <source>Unknown audio driver</source>
        <translation>Pilote audio inconnu</translation>
    </message>
    <message>
        <source>Error starting audio driver</source>
        <translation>Erreur au lancement du pilote audio</translation>
    </message>
    <message>
        <source>Jack driver: server shutdown</source>
        <translation>Pilote Jack : fermeture du serveur</translation>
    </message>
    <message>
        <source>Jack driver: cannot activate client</source>
        <translation>Pilote jack : impossible d&apos;activer le client</translation>
    </message>
    <message>
        <source>Jack driver: cannot connect output port</source>
        <translation>Pilote jack : impossible de connecter le port de sortie</translation>
    </message>
    <message>
        <source>Jack driver: error in port register</source>
        <translation>Pilote jack : impossible d&apos;authentifier le client</translation>
    </message>
    <message>
        <source>Unknown error</source>
        <translation>Erreur inconnue</translation>
    </message>
    <message>
        <source>Audio files (*.wav *.WAV *.au *.AU *.aiff *.AIFF)</source>
        <translation type="obsolete">Fichiers Audio (*.wav *.WAV *.au *.AU *.aiff *.AIFF)</translation>
    </message>
</context>
<context>
    <name>InstrumentPropertiesDialog</name>
    <message>
        <source>Hydrogen - Instrument properties</source>
        <translation type="obsolete">Hydrogen - Propriétés de l&apos;instrument</translation>
    </message>
    <message>
        <source>Instrument properties</source>
        <translation>Propriétés de l&apos;Instrument</translation>
    </message>
    <message>
        <source>Audio files (*.wav *.WAV *.au *.AU *.aiff *.AIFF *.flac *.FLAC)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Hydrogen - Load instrument</source>
        <translation type="unfinished">Hydrogen - Charger instrument</translation>
    </message>
    <message>
        <source>Set FX %1 level </source>
        <translation type="unfinished">Régler le niveau de l&apos;effet %1</translation>
    </message>
    <message>
        <source>Empty layer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Instrument name</source>
        <translation type="unfinished">Nom de l&apos;instrument</translation>
    </message>
</context>
<context>
    <name>InstrumentPropertiesDialog_UI</name>
    <message>
        <source>Form1</source>
        <translation></translation>
    </message>
    <message>
        <source>Instrument name</source>
        <translation type="obsolete">Nom de l&apos;instrument</translation>
    </message>
    <message>
        <source>Sample filename</source>
        <translation type="obsolete">Nom du fichier échantillon</translation>
    </message>
    <message>
        <source>Browse</source>
        <translation>Explorer</translation>
    </message>
    <message>
        <source>Drumkit</source>
        <translation type="obsolete">Kit de Batterie</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="obsolete">Annuler</translation>
    </message>
    <message>
        <source>Ok</source>
        <translation type="obsolete">OK</translation>
    </message>
    <message>
        <source>1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>3</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>4</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>5</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>6</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>7</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>8</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Play layer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Gain</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Pitch</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>End velocity</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Start velocity</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>sample size in frames</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delete</source>
        <translation type="unfinished">Effacer
</translation>
    </message>
</context>
<context>
    <name>LadspaFXMixerLine</name>
    <message>
        <source>FX on/off</source>
        <translation>Effet on/off</translation>
    </message>
    <message>
        <source>Edit FX parameters</source>
        <translation>Editer les paramètres d&apos;effet</translation>
    </message>
    <message>
        <source>Ladspa FX name (double click to change FX)</source>
        <translation>Nom de l&apos;effet LADSPA (double clic pour changer d&apos;effet)</translation>
    </message>
</context>
<context>
    <name>LadspaFXProperties</name>
    <message>
        <source>Select FX</source>
        <translation>Choisir Effet</translation>
    </message>
    <message>
        <source>[%1] LADSPA FX Properties</source>
        <translation>[%1] Propriétés de l&apos;effet LADSPA</translation>
    </message>
    <message>
        <source>LADSPA FX %1 Properties</source>
        <translation>Propriétés de l&apos;effet LADSPA</translation>
    </message>
    <message>
        <source>No plugin</source>
        <translation>Pas de plugin</translation>
    </message>
    <message>
        <source>Activate</source>
        <translation>Activer</translation>
    </message>
    <message>
        <source>Deactivate</source>
        <translation>Désactiver</translation>
    </message>
</context>
<context>
    <name>LadspaFXSelector</name>
    <message>
        <source>Groups</source>
        <translation>Groupes</translation>
    </message>
    <message>
        <source>Uncategorized</source>
        <translation>Sans catégorie</translation>
    </message>
    <message>
        <source>Stereo</source>
        <translation>Stéréo</translation>
    </message>
    <message>
        <source>Mono</source>
        <translation>Mono</translation>
    </message>
    <message>
        <source>Not supported</source>
        <translation>Pas de support</translation>
    </message>
    <message>
        <source>Select LADSPA FX</source>
        <translation>Choisir Effet LADSPA</translation>
    </message>
    <message>
        <source>Categorized (LRDF)</source>
        <translation>Catégorisés (LRDF)</translation>
    </message>
</context>
<context>
    <name>LadspaFXSelector_UI</name>
    <message>
        <source>Form1</source>
        <translation>Form1</translation>
    </message>
    <message>
        <source>Categories</source>
        <translation>Catégories</translation>
    </message>
    <message>
        <source>Groups</source>
        <translation>Groupes</translation>
    </message>
    <message>
        <source>test</source>
        <translation>test</translation>
    </message>
    <message>
        <source>Subitem-------</source>
        <translation>Sous-élément---</translation>
    </message>
    <message>
        <source>LADSPA plugins</source>
        <translation>Plugins LADSPA</translation>
    </message>
    <message>
        <source>New Item</source>
        <translation>Nouvel Element</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
    <message>
        <source>Ok</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Plugin info</source>
        <translation>Informations du plugin</translation>
    </message>
    <message>
        <source>Name:</source>
        <translation>Nom:</translation>
    </message>
    <message>
        <source>### fx name</source>
        <translation>### nom de l&apos;effet</translation>
    </message>
    <message>
        <source>Label:</source>
        <translation>Label:</translation>
    </message>
    <message>
        <source>### fx label</source>
        <translation>### label de l&apos;effet</translation>
    </message>
    <message>
        <source>Type:</source>
        <translation>Type:</translation>
    </message>
    <message>
        <source>ID:</source>
        <translation>ID:</translation>
    </message>
    <message>
        <source>### fx type</source>
        <translation>### type d&apos;effet</translation>
    </message>
    <message>
        <source>### fx ID</source>
        <translation>### ID de l&apos;effet</translation>
    </message>
    <message>
        <source>Maker:</source>
        <translation>Créateur:</translation>
    </message>
    <message>
        <source>### FX maker
1
2
3
4</source>
        <translation>### Créateur de l&apos;effet
1
2
3
4</translation>
    </message>
    <message>
        <source>Copyright:</source>
        <translation>Copyright:</translation>
    </message>
    <message>
        <source>### copyright
1
2
3
4</source>
        <translation>### copyright
1
2
3
4</translation>
    </message>
</context>
<context>
    <name>MainForm</name>
    <message>
        <source>Error loading song.</source>
        <translation>Erreur au chargement du morceau.</translation>
    </message>
    <message>
        <source>Error restoring last song.</source>
        <translation>Erreur lors de la restauration du morceau précédent.</translation>
    </message>
    <message>
        <source>Hydrogen Ready.</source>
        <translation>Hydrogen est prêt.</translation>
    </message>
    <message>
        <source>Open</source>
        <translation type="obsolete">Ouvrir</translation>
    </message>
    <message>
        <source>Open Demo</source>
        <translation type="obsolete">Ouvrir une démo</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation type="obsolete">Sortie</translation>
    </message>
    <message>
        <source>New</source>
        <translation type="obsolete">Nouveau</translation>
    </message>
    <message>
        <source>Save as...</source>
        <translation type="obsolete">Enregistrer sous...</translation>
    </message>
    <message>
        <source>Export</source>
        <translation type="obsolete">Exporter</translation>
    </message>
    <message>
        <source>Preferences</source>
        <translation type="obsolete">Préférences</translation>
    </message>
    <message>
        <source>Show mixer</source>
        <translation type="obsolete">Montrer la table de mixage</translation>
    </message>
    <message>
        <source>Show audio engine info</source>
        <translation type="obsolete">Montrer les infos du système audio</translation>
    </message>
    <message>
        <source>Show song editor</source>
        <translation type="obsolete">Montrer l&apos;éditeur de morceau</translation>
    </message>
    <message>
        <source>Show drumkit manager</source>
        <translation type="obsolete">Montrer le gestionnaire de kit de batterie</translation>
    </message>
    <message>
        <source>User manual</source>
        <translation type="obsolete">Manuel Utilisateur</translation>
    </message>
    <message>
        <source>About</source>
        <translation type="obsolete">A propos</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>&amp;Fichier</translation>
    </message>
    <message>
        <source>&amp;Window</source>
        <translation>F&amp;enêtres</translation>
    </message>
    <message>
        <source>?</source>
        <translation>?</translation>
    </message>
    <message>
        <source>
The song has unsaved changes
Do you want to save the changes before exiting?
</source>
        <translation>
Le morceau contient des informations non sauvegardées
Voulez-vous enregistrer les changements avant de quitter?</translation>
    </message>
    <message>
        <source>&amp;Save</source>
        <translation>&amp;Sauvegarder</translation>
    </message>
    <message>
        <source>&amp;Discard</source>
        <translation>&amp;Détruire</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
    <message>
        <source>
The document contains unsaved changes
Do you want to save the changes before exiting?
</source>
        <translation>
Le document contient des informations non sauvegardées
Voulez-vous enregistrer les changements avant de quitter?</translation>
    </message>
    <message>
        <source>Hydrogen Song (*.h2song)</source>
        <translation>Morceau Hydrogen (*.h2song)</translation>
    </message>
    <message>
        <source>Hydrogen - Save song</source>
        <translation type="obsolete">Hydrogen - Sauvegarder Morceau</translation>
    </message>
    <message>
        <source>Hydrogen - Open song</source>
        <translation type="obsolete">Hydrogen - Charger Morceau</translation>
    </message>
    <message>
        <source>Save song</source>
        <translation>Sauvegarder le morceau</translation>
    </message>
    <message>
        <source>Open song</source>
        <translation>Ouvrir un morceau</translation>
    </message>
    <message>
        <source>Quit</source>
        <translation type="obsolete">Quitter</translation>
    </message>
    <message>
        <source>Open recent</source>
        <translation type="obsolete">Récemment ouvert</translation>
    </message>
    <message>
        <source>Save</source>
        <translation type="obsolete">Sauvegarde</translation>
    </message>
    <message>
        <source>Export MIDI file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Midi file (*.mid)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Open</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Open &amp;Demo</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Open &amp;recent</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Save &amp;as...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Export</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Export &amp;MIDI file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Preferences</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show &amp;mixer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show &amp;song editor</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show &amp;drumkit manager</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show &amp;instrument editor</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show &amp;audio engine info</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;User manual</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Debug</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MasterMixerLine</name>
    <message>
        <source>Peak volume (left channel)</source>
        <translation>Volume maximum (canal gauche)</translation>
    </message>
    <message>
        <source>Master output</source>
        <translation>Niveau général de sortie</translation>
    </message>
    <message>
        <source>Set master volume [</source>
        <translation type="obsolete">Régler le niveau général de sortie [</translation>
    </message>
    <message>
        <source>Set master volume [%1]</source>
        <translation>Régler le volume principal [%1]</translation>
    </message>
</context>
<context>
    <name>Mixer</name>
    <message>
        <source>Hydrogen - Mixer</source>
        <translation type="obsolete">Hydrogen - Table de Mixage</translation>
    </message>
    <message>
        <source>Show faders panel</source>
        <translation>Montrer les curseurs</translation>
    </message>
    <message>
        <source>Show FX panel</source>
        <translation>Montrer les effets</translation>
    </message>
    <message>
        <source>Show instrument peaks</source>
        <translation>Montrer les niveaux</translation>
    </message>
    <message>
        <source>Swing factor</source>
        <translation>Facteur de swing</translation>
    </message>
    <message>
        <source>Human time</source>
        <translation>Temps &quot;humain&quot;</translation>
    </message>
    <message>
        <source>Human velocity</source>
        <translation>Vélocité &quot;humaine&quot;</translation>
    </message>
    <message>
        <source>Delay FX</source>
        <translation type="obsolete">Effet d&apos;écho</translation>
    </message>
    <message>
        <source>Set humanize time parameter [</source>
        <translation type="obsolete">Ajuster le paramètre de temps &quot;humain&quot; [</translation>
    </message>
    <message>
        <source>Set humanize velocity parameter [</source>
        <translation type="obsolete">Ajuster le paramètre de vélocité &quot;humaine&quot; [</translation>
    </message>
    <message>
        <source>Set swing factor [</source>
        <translation type="obsolete">Ajuster le facteur de swing [</translation>
    </message>
    <message>
        <source>Set delay wet level [</source>
        <translation type="obsolete">Ajuster le niveau d&apos;écho traité [</translation>
    </message>
    <message>
        <source>Delay FX enabled</source>
        <translation type="obsolete">Effet d&apos;écho actif</translation>
    </message>
    <message>
        <source>Delay FX disabled</source>
        <translation type="obsolete">Effet d&apos;écho inactif</translation>
    </message>
    <message>
        <source>Humanize Time FX enabled</source>
        <translation>Temps &quot;humain&quot; actif</translation>
    </message>
    <message>
        <source>Humanize Time FX disabled</source>
        <translation>Temps &quot;humain&quot; inactif</translation>
    </message>
    <message>
        <source>Humanize Velocity FX enabled</source>
        <translation>Vélocité &quot;humaine&quot; active</translation>
    </message>
    <message>
        <source>Humanize Velocity FX disabled</source>
        <translation>Vélocité &quot;humaine&quot; inactive</translation>
    </message>
    <message>
        <source>Swing factor FX enabled</source>
        <translation>Facteur de swing actif</translation>
    </message>
    <message>
        <source>Swing factor FX disabled</source>
        <translation>Facteur de swing inactif</translation>
    </message>
    <message>
        <source>Show instrument peaks = On</source>
        <translation>Montrer les niveaux = On</translation>
    </message>
    <message>
        <source>Show instrument peaks = Off</source>
        <translation>Montrer les niveaux = Off</translation>
    </message>
    <message>
        <source>No plugin</source>
        <translation>Pas de plugin</translation>
    </message>
    <message>
        <source>Mixer</source>
        <translation>Table de Mixage</translation>
    </message>
    <message>
        <source>Set humanize time parameter [%1]</source>
        <translation>Régler les paramètres de tempi humanisés [%1]</translation>
    </message>
    <message>
        <source>Set humanize velocity parameter [%1]</source>
        <translation>Régler les paramètres de vélocité humanisée [%1]</translation>
    </message>
    <message>
        <source>Set swing factor [%1]</source>
        <translation>Régler le facteur de swing [%1]</translation>
    </message>
    <message>
        <source>Set FX %1 level </source>
        <translation>Régler le niveau de l&apos;effet %1</translation>
    </message>
    <message>
        <source>Set LADSPA FX ( %1 ) volume</source>
        <translation>Régler le volume de l&apos;effet LADSPA (%1)</translation>
    </message>
    <message>
        <source>Instrument name</source>
        <translation type="unfinished">Nom de l&apos;instrument</translation>
    </message>
</context>
<context>
    <name>MixerLine</name>
    <message>
        <source>Play sample</source>
        <translation>Jouer échantillon</translation>
    </message>
    <message>
        <source>Load external sample</source>
        <translation type="obsolete">Charger un échantillon externe</translation>
    </message>
    <message>
        <source>Mute</source>
        <translation>Muet</translation>
    </message>
    <message>
        <source>Solo</source>
        <translation>Solo</translation>
    </message>
    <message>
        <source>Delay</source>
        <translation type="obsolete">Echo</translation>
    </message>
    <message>
        <source>Pan</source>
        <translation>Pan</translation>
    </message>
    <message>
        <source>Peak volume</source>
        <translation>Niveau sonore</translation>
    </message>
    <message>
        <source>Instrument name (double click to edit)</source>
        <translation>Nom de l&apos;instrument (double cliquer pour éditer)</translation>
    </message>
    <message>
        <source>Set instrument volume [</source>
        <translation type="obsolete">Ajuster le volume de l&apos;instrument [</translation>
    </message>
    <message>
        <source>Set instrument pan [</source>
        <translation type="obsolete">Ajuster le panoramique de l&apos;instrument [</translation>
    </message>
    <message>
        <source>Set instrument delay [</source>
        <translation type="obsolete">Ajuster l&apos;écho de l&apos;instrument [</translation>
    </message>
    <message>
        <source>Set instrument volume [%1]</source>
        <translation>Régler le volume de l&apos;instrument [%1]</translation>
    </message>
    <message>
        <source>Set instrument pan [%1]</source>
        <translation>Régler le panoramique de l&apos;instrument [%1]</translation>
    </message>
</context>
<context>
    <name>PatternEditorPanel</name>
    <message>
        <source>Pattern Editor</source>
        <translation>Editeur de Motif</translation>
    </message>
    <message>
        <source>Grid resolution</source>
        <translation>Résol. de la grille</translation>
    </message>
    <message>
        <source>Hear new notes</source>
        <translation>Entendre les notes ajoutées</translation>
    </message>
    <message>
        <source>Pattern name</source>
        <translation>Nom du Motif</translation>
    </message>
    <message>
        <source>4</source>
        <translation></translation>
    </message>
    <message>
        <source>8</source>
        <translation></translation>
    </message>
    <message>
        <source>16</source>
        <translation></translation>
    </message>
    <message>
        <source>32</source>
        <translation></translation>
    </message>
    <message>
        <source>64</source>
        <translation></translation>
    </message>
    <message>
        <source>4T</source>
        <translation></translation>
    </message>
    <message>
        <source>8T</source>
        <translation></translation>
    </message>
    <message>
        <source>16T</source>
        <translation></translation>
    </message>
    <message>
        <source>32T</source>
        <translation></translation>
    </message>
    <message>
        <source>1</source>
        <translation></translation>
    </message>
    <message>
        <source>2</source>
        <translation></translation>
    </message>
    <message>
        <source>3</source>
        <translation></translation>
    </message>
    <message>
        <source>5</source>
        <translation></translation>
    </message>
    <message>
        <source>6</source>
        <translation></translation>
    </message>
    <message>
        <source>7</source>
        <translation></translation>
    </message>
    <message>
        <source>Pattern size</source>
        <translation>Taille du Motif</translation>
    </message>
    <message>
        <source>Pattern editor - </source>
        <translation type="obsolete">Editeur de Motif - </translation>
    </message>
    <message>
        <source>&lt;b&gt;No pattern selected! (NULL pattern)&lt;/b&gt;</source>
        <translation type="obsolete">&lt;b&gt;Aucun motif sélectionné ! (motif VIDE)&lt;/b&gt;</translation>
    </message>
    <message>
        <source>No pattern selected! (NULL pattern)</source>
        <translation type="obsolete">Aucun motif sélectionné ! (motif VIDE)</translation>
    </message>
    <message>
        <source>Pattern name: &lt;b&gt;</source>
        <translation type="obsolete">Nom du Motif : &lt;b&gt;</translation>
    </message>
    <message>
        <source>Hear new notes = On</source>
        <translation>Entendre notes ajoutées = On</translation>
    </message>
    <message>
        <source>Hear new notes = Off</source>
        <translation>Entendre notes ajoutées = Off</translation>
    </message>
    <message>
        <source>Pattern editor - %1</source>
        <translation>Editeur de motif - %1</translation>
    </message>
    <message>
        <source>Record keyboard/midi events</source>
        <translation>Enregistrer les évenements de clavier/MIDI</translation>
    </message>
    <message>
        <source>Quantize keyboard/midi events to grid</source>
        <translation>Quantifier les évenements clavier/MIDI sur la grille</translation>
    </message>
    <message>
        <source>Record keyboard/midi events = On</source>
        <translation>Enregistrement des évenements clavier/MIDI = On</translation>
    </message>
    <message>
        <source>Record keyboard/midi events = Off</source>
        <translation>Enregistrement des évenements clavier/MIDI = Off</translation>
    </message>
    <message>
        <source>Quantize incoming keyboard/midi events = On</source>
        <translation>Quantifier les évenements clavier/MIDI entrant = On</translation>
    </message>
    <message>
        <source>Quantize incoming keyboard/midi events = Off</source>
        <translation>Quantifier les évenements clavier/MIDI entrant = Off</translation>
    </message>
    <message>
        <source>Pattern name: &lt;b&gt;%1&lt;/b&gt;</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PatternPropertiesDialog</name>
    <message>
        <source>Hydrogen - Pattern properties</source>
        <translation type="obsolete">Hydrogen - Propriétés du Motif</translation>
    </message>
    <message>
        <source>Pattern properties</source>
        <translation>Propriétés du motif</translation>
    </message>
</context>
<context>
    <name>PatternPropertiesDialog_UI</name>
    <message>
        <source>Form1</source>
        <translation></translation>
    </message>
    <message>
        <source>Pattern Name</source>
        <translation>Nom du Motif</translation>
    </message>
    <message>
        <source> Ok </source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
</context>
<context>
    <name>PlayerControl</name>
    <message>
        <source>Play</source>
        <translation>Jouer</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Arrêter</translation>
    </message>
    <message>
        <source>Song Mode</source>
        <translation>Mode Morceau</translation>
    </message>
    <message>
        <source>Pattern Mode</source>
        <translation>Mode Motif</translation>
    </message>
    <message>
        <source>BPM</source>
        <translation>Métronome</translation>
    </message>
    <message>
        <source>Play button disabled while using jack-transport slave mode.</source>
        <translation type="obsolete">Button de lecture désactivé lorsque le mode jack-transport esclave est actif.</translation>
    </message>
    <message>
        <source>Playing.</source>
        <translation>Lecture.</translation>
    </message>
    <message>
        <source>Stop button disabled while using jack-transport slave mode.</source>
        <translation type="obsolete">Button d&apos;arrêt désactivé lorsque le mode jack-transport esclave est actif.</translation>
    </message>
    <message>
        <source>Stopped.</source>
        <translation>Arrêté.</translation>
    </message>
    <message>
        <source>Song mode selected.</source>
        <translation>Mode Morceau sélectionné.</translation>
    </message>
    <message>
        <source>Pattern mode selected.</source>
        <translation>Mode Motif sélectionné.</translation>
    </message>
    <message>
        <source>Jack-transport on/off</source>
        <translation>Transport Jack on/off</translation>
    </message>
    <message>
        <source>Jack-transport mode = On</source>
        <translation>Transport Jack = On</translation>
    </message>
    <message>
        <source>Jack-transport mode = Off</source>
        <translation>Transport Jack = Off</translation>
    </message>
</context>
<context>
    <name>PreferencesDialog</name>
    <message>
        <source>Hydrogen - Preferences</source>
        <translation type="obsolete">Hydrogen - Préférences</translation>
    </message>
    <message>
        <source>Slow</source>
        <translation>Lent</translation>
    </message>
    <message>
        <source>Normal</source>
        <translation>Normal</translation>
    </message>
    <message>
        <source>Fast</source>
        <translation>Rapide</translation>
    </message>
    <message>
        <source>&lt;b&gt;NULL DRIVER&lt;/b&gt;&lt;br&gt;Please select an audio driver&lt;br&gt;</source>
        <translation type="obsolete">&lt;b&gt;PILOTE NUL&lt;/b&gt;&lt;br&gt;Veuillez sélectionner un pilote audio&lt;br&gt;</translation>
    </message>
    <message>
        <source>&lt;b&gt;Open Sound System&lt;/b&gt;&lt;br&gt;Simple audio driver [/dev/dsp]</source>
        <translation>&lt;b&gt;Open Sound System&lt;/b&gt;&lt;br&gt;Pilote audio simple [/dev/dsp]</translation>
    </message>
    <message>
        <source>&lt;br&gt;&lt;b&gt;&lt;font color=&quot;red&quot;&gt;Not compiled&lt;/font&gt;&lt;/b&gt;</source>
        <translation>&lt;br&gt;&lt;b&gt;&lt;font color=&quot;red&quot;&gt;Non compilé&lt;/font&gt;&lt;/b&gt;</translation>
    </message>
    <message>
        <source>&lt;b&gt;Jack Audio Connection Kit Driver&lt;/b&gt;&lt;br&gt;Low latency audio driver</source>
        <translation>&lt;b&gt;Pilote Jack Audio Connection Kit&lt;/b&gt;&lt;br&gt;Pilote audio faible latence</translation>
    </message>
    <message>
        <source>Preferences</source>
        <translation>Préférences</translation>
    </message>
</context>
<context>
    <name>PreferencesDialog_UI</name>
    <message>
        <source>Form1</source>
        <translation></translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
    <message>
        <source>Ok</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>General</source>
        <translation>Général</translation>
    </message>
    <message>
        <source>Restore last used song</source>
        <translation>Restaurer le dernier morceau travaillé</translation>
    </message>
    <message>
        <source>Audio System</source>
        <translation>Système Audio</translation>
    </message>
    <message>
        <source>Audio driver</source>
        <translation>Pilote Audio</translation>
    </message>
    <message>
        <source>Oss</source>
        <translation>OSS</translation>
    </message>
    <message>
        <source>Jack</source>
        <translation>JACK</translation>
    </message>
    <message>
        <source>Restart driver</source>
        <translation>Relancer le pilote</translation>
    </message>
    <message>
        <source>###</source>
        <translation></translation>
    </message>
    <message>
        <source>22050</source>
        <translation></translation>
    </message>
    <message>
        <source>44100</source>
        <translation></translation>
    </message>
    <message>
        <source>48000</source>
        <translation></translation>
    </message>
    <message>
        <source>Sample rate</source>
        <translation>Taux d&apos;échantillonage</translation>
    </message>
    <message>
        <source>Device</source>
        <translation>Carte</translation>
    </message>
    <message>
        <source>Jack Transport Slave</source>
        <translation type="obsolete">Esclave JACK Transport</translation>
    </message>
    <message>
        <source>Buffer size</source>
        <translation>Taille du tampon</translation>
    </message>
    <message>
        <source>Connect to Default Output Pair</source>
        <translation>Se connecter à la sortie par défaut</translation>
    </message>
    <message>
        <source>Enable Track Outputs</source>
        <translation>Activer la Sortie des pistes</translation>
    </message>
    <message>
        <source>Metronome</source>
        <translation>Métronome</translation>
    </message>
    <message>
        <source>Enabled</source>
        <translation>Activé</translation>
    </message>
    <message>
        <source>Volume</source>
        <translation>Volume</translation>
    </message>
    <message>
        <source>Max notes</source>
        <translation>Nombre maximum de notes</translation>
    </message>
    <message>
        <source>Polyphony</source>
        <translation>Polyphonie</translation>
    </message>
    <message>
        <source>Midi System</source>
        <translation>Système MIDI</translation>
    </message>
    <message>
        <source>Midi Input</source>
        <translation>Entrée MIDI</translation>
    </message>
    <message>
        <source>Input</source>
        <translation>Entrée</translation>
    </message>
    <message>
        <source>Channel</source>
        <translation>Canal</translation>
    </message>
    <message>
        <source>All</source>
        <translation>Tous</translation>
    </message>
    <message>
        <source>1</source>
        <translation></translation>
    </message>
    <message>
        <source>2</source>
        <translation></translation>
    </message>
    <message>
        <source>3</source>
        <translation></translation>
    </message>
    <message>
        <source>4</source>
        <translation></translation>
    </message>
    <message>
        <source>5</source>
        <translation></translation>
    </message>
    <message>
        <source>6</source>
        <translation></translation>
    </message>
    <message>
        <source>7</source>
        <translation></translation>
    </message>
    <message>
        <source>8</source>
        <translation></translation>
    </message>
    <message>
        <source>9</source>
        <translation></translation>
    </message>
    <message>
        <source>10</source>
        <translation></translation>
    </message>
    <message>
        <source>11</source>
        <translation></translation>
    </message>
    <message>
        <source>12</source>
        <translation></translation>
    </message>
    <message>
        <source>13</source>
        <translation></translation>
    </message>
    <message>
        <source>14</source>
        <translation></translation>
    </message>
    <message>
        <source>15</source>
        <translation></translation>
    </message>
    <message>
        <source>16</source>
        <translation></translation>
    </message>
    <message>
        <source>Appearance</source>
        <translation>Apparence</translation>
    </message>
    <message>
        <source>Mixer</source>
        <translation>Table de Mixage</translation>
    </message>
    <message>
        <source>Slow</source>
        <translation>Lent</translation>
    </message>
    <message>
        <source>Normal</source>
        <translation>Normal</translation>
    </message>
    <message>
        <source>Fast</source>
        <translation>Rapide</translation>
    </message>
    <message>
        <source>Meters falloff speed</source>
        <translation>Vitesse de chute des niveaux</translation>
    </message>
    <message>
        <source>Fonts</source>
        <translation type="obsolete">Fontes</translation>
    </message>
    <message>
        <source>Application font</source>
        <translation>Fontes de l&apos;application</translation>
    </message>
    <message>
        <source>Select font</source>
        <translation>Choisir la fonte</translation>
    </message>
    <message>
        <source>Mixer font</source>
        <translation>Fonte de la table de mixage</translation>
    </message>
    <message>
        <source>&lt;i&gt;After a font change the application must be restarted.&lt;/i&gt;</source>
        <translation>&lt;i&gt;Après un changement de fontes, l&apos;application doit être relancée.&lt;/i&gt;</translation>
    </message>
    <message>
        <source>Application interface</source>
        <translation type="obsolete">Interface de l&apos;application</translation>
    </message>
    <message>
        <source>Interface mode</source>
        <translation>Mode de l&apos;interface</translation>
    </message>
    <message>
        <source>Child frame</source>
        <translation>Parent-Enfants</translation>
    </message>
    <message>
        <source>Top level</source>
        <translation>Vue générale</translation>
    </message>
    <message>
        <source>&lt;i&gt;After a change the application must be restarted.&lt;/i&gt;</source>
        <translation>&lt;i&gt;Après un changement, l&apos;application doit être relancée.&lt;/i&gt;</translation>
    </message>
    <message>
        <source>LADSPA Plugin path</source>
        <translation type="obsolete">Chemin des plugins LADSPA</translation>
    </message>
    <message>
        <source>Application</source>
        <translation>Application</translation>
    </message>
    <message>
        <source>Style</source>
        <translation>Style</translation>
    </message>
    <message>
        <source>Single paned</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SongEditorPanel</name>
    <message>
        <source>Hydrogen - Song Editor</source>
        <translation type="obsolete">Hydrogen - Editeur de Morceau</translation>
    </message>
    <message>
        <source>Create new pattern</source>
        <translation>Créer un nouveau motif</translation>
    </message>
    <message>
        <source>Move the selected pattern down</source>
        <translation>Mettre le motif sélectionné en dessous</translation>
    </message>
    <message>
        <source>Move the selected pattern up</source>
        <translation>Mettre le motif sélectionné au dessus</translation>
    </message>
    <message>
        <source>Song operations</source>
        <translation>Opérations sur le morceau</translation>
    </message>
    <message>
        <source>Song loop</source>
        <translation>Morceau en boucle</translation>
    </message>
    <message>
        <source>Song properties</source>
        <translation>Propriétés du morceau</translation>
    </message>
    <message>
        <source>Clear pattern sequence</source>
        <translation></translation>
    </message>
    <message>
        <source>Delete all patterns</source>
        <translation>Effacer tous les motifs</translation>
    </message>
    <message>
        <source>Song Editor</source>
        <translation>Editeur de morceau</translation>
    </message>
</context>
<context>
    <name>SongEditorPatternList</name>
    <message>
        <source>Edit</source>
        <translation>Editer</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Copier</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Effacer
</translation>
    </message>
    <message>
        <source>Properties</source>
        <translation>Propriétés</translation>
    </message>
    <message>
        <source>Can&apos;t delete the pattern while the audio engine is playing</source>
        <translation type="obsolete">Impossible d&apos;effacer le motif alors que le système audio est actif</translation>
    </message>
</context>
<context>
    <name>SongPropertiesDialog</name>
    <message>
        <source>Hydrogen - Song properties</source>
        <translation type="obsolete">Hydrogen - Propriétés du morceau</translation>
    </message>
    <message>
        <source>Song properties</source>
        <translation>Propriétés du morceau</translation>
    </message>
</context>
<context>
    <name>SongPropertiesDialog_UI</name>
    <message>
        <source>Form1</source>
        <translation></translation>
    </message>
    <message>
        <source>Song name</source>
        <translation>Nom du morceau</translation>
    </message>
    <message>
        <source>Author</source>
        <translation>Auteur</translation>
    </message>
    <message>
        <source>Notes</source>
        <translation>Notes</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
    <message>
        <source> Ok </source>
        <translation>OK</translation>
    </message>
</context>
<context>
    <name>SplashScreen</name>
    <message>
        <source>Hydrogen</source>
        <translation>Hydrogen</translation>
    </message>
    <message>
        <source>Alpha Version </source>
        <translation type="obsolete">Version Alpha</translation>
    </message>
    <message>
        <source>Modules: </source>
        <translation type="obsolete">Modules :</translation>
    </message>
</context>
</TS>
